# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
try:
    import otg_pb2 as otg__pb2
except ImportError:
    from snappi import otg_pb2 as otg__pb2


class OpenapiStub(object):
    """Description missing in models

    For all RPCs defined in this service, API Server SHOULD provide JSON
    representation of `Error` message as an error string upon failure, ensuring
    name of enum constants (instead of value) for `kind` property is present
    in the representation
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetConfig = channel.unary_unary(
                '/otg.Openapi/SetConfig',
                request_serializer=otg__pb2.SetConfigRequest.SerializeToString,
                response_deserializer=otg__pb2.SetConfigResponse.FromString,
                )
        self.GetConfig = channel.unary_unary(
                '/otg.Openapi/GetConfig',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=otg__pb2.GetConfigResponse.FromString,
                )
        self.UpdateConfig = channel.unary_unary(
                '/otg.Openapi/UpdateConfig',
                request_serializer=otg__pb2.UpdateConfigRequest.SerializeToString,
                response_deserializer=otg__pb2.UpdateConfigResponse.FromString,
                )
        self.SetControlState = channel.unary_unary(
                '/otg.Openapi/SetControlState',
                request_serializer=otg__pb2.SetControlStateRequest.SerializeToString,
                response_deserializer=otg__pb2.SetControlStateResponse.FromString,
                )
        self.SetControlAction = channel.unary_unary(
                '/otg.Openapi/SetControlAction',
                request_serializer=otg__pb2.SetControlActionRequest.SerializeToString,
                response_deserializer=otg__pb2.SetControlActionResponse.FromString,
                )
        self.GetMetrics = channel.unary_unary(
                '/otg.Openapi/GetMetrics',
                request_serializer=otg__pb2.GetMetricsRequest.SerializeToString,
                response_deserializer=otg__pb2.GetMetricsResponse.FromString,
                )
        self.GetStates = channel.unary_unary(
                '/otg.Openapi/GetStates',
                request_serializer=otg__pb2.GetStatesRequest.SerializeToString,
                response_deserializer=otg__pb2.GetStatesResponse.FromString,
                )
        self.GetCapture = channel.unary_unary(
                '/otg.Openapi/GetCapture',
                request_serializer=otg__pb2.GetCaptureRequest.SerializeToString,
                response_deserializer=otg__pb2.GetCaptureResponse.FromString,
                )
        self.GetVersion = channel.unary_unary(
                '/otg.Openapi/GetVersion',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=otg__pb2.GetVersionResponse.FromString,
                )


class OpenapiServicer(object):
    """Description missing in models

    For all RPCs defined in this service, API Server SHOULD provide JSON
    representation of `Error` message as an error string upon failure, ensuring
    name of enum constants (instead of value) for `kind` property is present
    in the representation
    """

    def SetConfig(self, request, context):
        """Sets configuration resources on the traffic generator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConfig(self, request, context):
        """Description missing in models
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateConfig(self, request, context):
        """Updates specific attributes of resources configured on the traffic generator. The
        fetched configuration shall reflect the updates applied successfully.
        The Response.Warnings in the Success response is available for implementers to disclose
        additional information about a state change including any implicit changes that are
        outside the scope of the state change.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetControlState(self, request, context):
        """Sets the operational state of configured resources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetControlAction(self, request, context):
        """Triggers actions against configured resources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMetrics(self, request, context):
        """Description missing in models
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStates(self, request, context):
        """Description missing in models
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCapture(self, request, context):
        """Description missing in models
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVersion(self, request, context):
        """Description missing in models
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OpenapiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.SetConfig,
                    request_deserializer=otg__pb2.SetConfigRequest.FromString,
                    response_serializer=otg__pb2.SetConfigResponse.SerializeToString,
            ),
            'GetConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConfig,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=otg__pb2.GetConfigResponse.SerializeToString,
            ),
            'UpdateConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateConfig,
                    request_deserializer=otg__pb2.UpdateConfigRequest.FromString,
                    response_serializer=otg__pb2.UpdateConfigResponse.SerializeToString,
            ),
            'SetControlState': grpc.unary_unary_rpc_method_handler(
                    servicer.SetControlState,
                    request_deserializer=otg__pb2.SetControlStateRequest.FromString,
                    response_serializer=otg__pb2.SetControlStateResponse.SerializeToString,
            ),
            'SetControlAction': grpc.unary_unary_rpc_method_handler(
                    servicer.SetControlAction,
                    request_deserializer=otg__pb2.SetControlActionRequest.FromString,
                    response_serializer=otg__pb2.SetControlActionResponse.SerializeToString,
            ),
            'GetMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMetrics,
                    request_deserializer=otg__pb2.GetMetricsRequest.FromString,
                    response_serializer=otg__pb2.GetMetricsResponse.SerializeToString,
            ),
            'GetStates': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStates,
                    request_deserializer=otg__pb2.GetStatesRequest.FromString,
                    response_serializer=otg__pb2.GetStatesResponse.SerializeToString,
            ),
            'GetCapture': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCapture,
                    request_deserializer=otg__pb2.GetCaptureRequest.FromString,
                    response_serializer=otg__pb2.GetCaptureResponse.SerializeToString,
            ),
            'GetVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVersion,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=otg__pb2.GetVersionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'otg.Openapi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Openapi(object):
    """Description missing in models

    For all RPCs defined in this service, API Server SHOULD provide JSON
    representation of `Error` message as an error string upon failure, ensuring
    name of enum constants (instead of value) for `kind` property is present
    in the representation
    """

    @staticmethod
    def SetConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/SetConfig',
            otg__pb2.SetConfigRequest.SerializeToString,
            otg__pb2.SetConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/GetConfig',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            otg__pb2.GetConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/UpdateConfig',
            otg__pb2.UpdateConfigRequest.SerializeToString,
            otg__pb2.UpdateConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetControlState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/SetControlState',
            otg__pb2.SetControlStateRequest.SerializeToString,
            otg__pb2.SetControlStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetControlAction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/SetControlAction',
            otg__pb2.SetControlActionRequest.SerializeToString,
            otg__pb2.SetControlActionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/GetMetrics',
            otg__pb2.GetMetricsRequest.SerializeToString,
            otg__pb2.GetMetricsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/GetStates',
            otg__pb2.GetStatesRequest.SerializeToString,
            otg__pb2.GetStatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCapture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/GetCapture',
            otg__pb2.GetCaptureRequest.SerializeToString,
            otg__pb2.GetCaptureResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/GetVersion',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            otg__pb2.GetVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import pytest


def test_device_stack(api):
    """Test device dual stack functionality
    """
    config = api.config()
    p1, p2 = config.ports.port(name='p1').port(name='p2')
    d = config.devices.device(name='d')[-1]
    e = d.ethernets.ethernet()[-1]
    e.connection.port_name = p1.name
    e.name = 'e'
    e.mac = '00:01:00:00:00:01'
    i4 = e.ipv4_addresses.ipv4()[-1]
    i4.name = 'i4'
    i4.address = '1.1.1.1'
    i4.gateway = '1.1.1.2'
    b4 = d.bgp.ipv4_interfaces.v4interface()[-1]
    b4.ipv4_name = i4.name
    b4.peers.v4peer()
    b4.peers[-1].name = "b4"
    b4.peers[-1].v4_routes.v4routerange(name="r1v4")
    b4.peers[-1].peer_address = '1.1.1.2'
    b4.peers[-1].as_type = b4.peers[-1].IBGP
    b4.peers[-1].as_number = 10
    d.bgp.router_id = "192.168.1.1"
    i6 = e.ipv6_addresses.ipv6()[-1]
    i6.name = 'i6'
    i6.address = '2001::1'
    i6.gateway = '2001::2'
    b6 = d.bgp.ipv6_interfaces.v6interface()[-1]
    b6.ipv6_name = i6.name
    b6.peers.v6peer()
    b6.peers[-1].peer_address = '2001::2'
    b6.peers[-1].as_type = 'ibgp'
    b6.peers[-1].as_number = 10
    b6.peers[-1].name = "b6"
    api.set_config(config)
    print(config)


if __name__ == '__main__':
    pytest.main(['-s', __file__])



import pytest


def get_mock_config(grpc_api):
    config = grpc_api.config()
    p1, p2 = config.ports.port(name="p1").port(name="p2")

    flow = config.flows.flow(name="Tx -> Rx Flow")[0]
    flow.tx_rx.port.tx_name = p1.name
    flow.tx_rx.port.rx_name = p2.name
    flow.size.fixed = 128
    flow.rate.pps = 1000
    flow.duration.fixed_packets.packets = 10000

    eth, ip = flow.packet.ethernet().ipv4()

    eth.src.value = "00:00:01:00:00:01"
    eth.dst.values = ["00:00:02:00:00:01", "00:00:02:00:00:01"]
    eth.dst.metric_tags.add(name="eth dst mac")

    ip.src.increment.start = "1.1.1.1"
    ip.src.increment.step = "0.0.0.1"
    ip.src.increment.count = 10

    ip.dst.decrement.start = "1.1.2.200"
    ip.dst.decrement.step = "0.0.0.1"
    ip.dst.decrement.count = 10

    ip.priority.dscp.phb.value = 16
    ip.priority.dscp.ecn.value = 1
    return config


def test_grpc_set_config(grpc_api):
    config = get_mock_config(grpc_api)
    response = grpc_api.set_config(config)
    assert len(response.warnings) == 1
    assert response.warnings[0] == "no"


def test_grpc_get_config(grpc_api):
    config = get_mock_config(grpc_api)
    response = grpc_api.get_config()
    assert config.serialize() == response.serialize()


if __name__ == "__main__":
    pytest.main(["-s", __file__])



import pytest
import snappi


def test_capture(api):
    """Test capture functionality

    Capture should allow for multiple filters.
    The capture.filters is a list of CaptureFilter objects which can be 
    CaptureCustom, CaptureEthernet, CaptureVlan and CaptureIpv4.
    A CaptureCustom object is used when packet header is not available.
    """
    config = api.config()

    # create a capture
    config.ports.port(name='port1').port(name='port2')
    capture = config.captures.capture()[0]
    capture.name = 'capture1'
    capture.port_names = [port.name for port in config.ports]

    # add 2 custom filters
    capture.filters.custom().custom()
    src_mac = capture.filters[0]  # type: snappi.CustomFilter
    src_mac.offset = 0
    src_mac.value = '000100000001'
    src_mac.mask = 'FFFFFFFFFFFF'
    dst_mac = capture.filters[1]  # type: snappi.CustomFilter
    dst_mac.offset = 0
    dst_mac.value = '000200000001'
    dst_mac.mask = 'FFFFFFFFFFFF'
    print(config)

    # add packet filters for inner and outer vlan
    capture.filters.clear()
    _, i_vlan, o_vlan = capture.filters.ethernet().vlan().vlan()
    i_vlan.id.value = '01'
    i_vlan.id.mask = 'FF'
    o_vlan.id.value = '03'
    o_vlan.id.mask = 'FF'
    print(config)

    # add packet filters for a custom packet after eth, ip
    capture.filters.clear()
    eth, _, custom = capture.filters.ethernet().ipv4().custom()
    eth.src.value = '000001000001'
    eth.src.mask = 'FFFFFFFFFFFF'
    custom.offset = 16
    custom.value = '010101'
    custom.mask = 'FFFFFF'
    print(config)

    api.set_config(config)


if __name__ == '__main__':
    pytest.main(['-vv', '-s', __file__])



import snappi


def test_get():
    config = snappi.Api().config()
    f = config.flows.flow()[-1]
    s = f.get('size')
    assert s == None
    s = f.get('size', False)
    assert s == None
    fixed = f.get('size', True).get('fixed', True)
    assert fixed == 64
    assert f._properties.get('size') == None
    r = f.get('rate', True)
    assert r != None
    assert f._properties.get('rate') == None



import pytest
import snappi


def test_slots(api):
    """Test that dynamically created attributes are disallowed.
    This is done by ensuring that the special variable __dict__ is not 
    present in any classes.
    The proper use of the special variable __slots__ ensures that the __dict__
    special variable will not be present unless it is specifically included
    in the __slots__.
    """
    base = snappi.snappi.OpenApiBase()
    assert('__dict__' not in dir(base))
    obj = snappi.snappi.OpenApiObject()
    assert('__dict__' not in dir(obj))
    config = api.config()
    assert('__dict__' not in dir(config))


if __name__ == '__main__':
    pytest.main(['-vv', '-s', __file__])
